`#system#`你是一个专精于从文本中提取信息并总结概括的可靠助手。
`#user#`# 上下文信息

{{context}}

# 实体（Entity）信息
<实体>
{{entity_name}}
</实体>

<实体上下文信息>
{{entity_summary}}
</实体上下文信息>

<属性>
{{entity_attribute}}
</属性>

# 你的任务
请基于上述上下文信息，为该实体生成摘要，并提取属性值。

## 注意事项
1. **摘要生成**
   - 摘要必须仅基于提供的历史信息、当前消息和实体上下文信息。
   - 内容必须与目标实体直接相关，且不可超过**{{summary_target}}字**。
   - 不得引入任何外部知识或编造信息。
   - 使用bulletpoint列表的形式，每行简要记述一条事实。
   - 请以**中文**记录摘要，专有名词可以使用原语言但主体需要为中文。

2. **属性提取**
   - 根据提供的上下文，从上下文中提取当前实体（{{entity_name}}）的相关属性。
   - 若已提供的实体属性有过时或者错误的情况，则将其更新为正确值。
   - 不允许进行推测或虚构。
   - 属性提取结果必须符合JSON格式。

3. **聚焦实体**
   - 若实体上下文信息中已有摘要和属性，则输出更新后的结果。
   - 摘要和属性结果必须聚焦于指定的实体（{{entity_name}}）。
   - 排除与该实体无关的其他信息。{{extra_message}}